@@ -50,8 +50,8 @@ setMethod(
         p <- ggplot() +
             geom_raster(
                 data = as.data.frame(s),
-                mapping = aes_string(x = "s1", y = "s2"),
-                fill   = rgb(0.5, 0.8, 0.5, 1.0)
+                mapping = aes(x = .data$s1, y = .data$s2),
+                fill = rgb(0.5, 0.8, 0.5, 1.0)
             ) +
             coord_fixed() +
             scale_x_continuous(name = sNames[1]) +
@@ -60,7 +60,8 @@ setMethod(
             p <- p +
                 geom_segment(
                     data = Br,
-                    mapping = aes_string(x = "x", y = "y", xend = "xend", yend = "yend"),
+                    mapping = aes(x = .data$x, y = .data$y,
+                                  xend = .data$xend, yend = .data$yend),
                     colour = rgb(0.8, 1.0, 0.8)
                 )
         }
@@ -68,7 +69,8 @@ setMethod(
             p <- p +
                 geom_segment(
                     data = Bc,
-                    mapping = aes_string(x = "x", y = "y", xend = "xend", yend = "yend"),
+                    mapping = aes(x = .data$x, y = .data$y,
+                                  xend = .data$xend, yend = .data$yend),
                     colour = rgb(0.8, 1.0, 0.8)
                 )
         }
@@ -90,10 +92,7 @@ setMethod(
         plot(x) +
             geom_point(
                 data = as.data.frame(s),
-                mapping = aes_string(
-                    x = "s1",
-                    y = "s2"
-                ),
+                mapping = aes(x = .data$s1, y = .data$s2),
                 colour = "black",
                 alpha = 0.4
             )
@@ -121,11 +120,7 @@ setMethod(
                         "new point"
                     )
                 ),
-                mapping = aes_string(
-                    x = "s1",
-                    y = "s2",
-                    shape = "type"
-                ),
+                mapping = aes(x = .data$s1, y = .data$s2, shape = .data$type),
                 colour = "black",
                 alpha = 0.4
             ) +
@@ -150,11 +145,8 @@ setMethod(
                     s,
                     composite = factor(y@composite)
                 ),
-                mapping = aes_string(
-                    x = "s1",
-                    y = "s2",
-                    shape = "composite"
-                ),
+                mapping = aes(x = .data$s1, y = .data$s2,
+                              shape = .data$composite),
                 colour = "black",
                 alpha = 0.4
             ) +
@@ -180,7 +172,7 @@ setMethod(
         ggplot() +
             geom_point(
                 data = as.data.frame(s),
-                mapping = aes_string(x = "s1", y = "s2"),
+                mapping = aes(x = .data$s1, y = .data$s2),
                 colour = "black",
                 alpha = 0.4
             ) +
@@ -215,11 +207,7 @@ setMethod(
                         "new point"
                     )
                 ),
-                mapping = aes_string(
-                    x = "s1",
-                    y = "s2",
-                    shape = "type"
-                ),
+                mapping = aes(x = .data$s1, y = .data$s2, shape = .data$type),
                 colour = "black",
                 alpha = 0.4
             ) +
@@ -251,11 +239,8 @@ setMethod(
                     s,
                     composite = factor(x@composite)
                 ),
-                mapping = aes_string(
-                    x = "s1",
-                    y = "s2",
-                    shape = "composite"
-                ),
+                mapping = aes(x = .data$s1, y = .data$s2,
+                              shape = .data$composite),
                 colour = "black",
                 alpha = 0.4
             ) +
